.. image:: https://github.com/rkimoakbioinformatics/oakvar/raw/master/oakvar/gui/websubmit/images/logo.png
  :width: 300
  :alt: OakVar logo

OakVar: Genomic Variant Analysis Platform
*****************************************

* Annotate genomic variants with diverse annotation sources.
* Make databases of annotated variants.
* Query annotated variants with filter sets.
* Make reports in diverse formats.
* Visualize annotated variants with graphical user interface.
* Works via CLI and GUI.
* Easily develop, run, and distribute CLI and GUI genomics apps. OakVar acts as an operating system for genomics apps.
* Connect genomic data to AI/ML models.

Internship available
====================
The main project will be OakVar. Full remote work. Potential to become full-time employment. Please send your application to rkim@oakbioinformatics.com.

Resources
=========
Ready to start? `OakVar Documentation`_

.. _OakVar Documentation: https://docs.oakvar.com

`Subscribe to the mailing list`_: Be in the loop and notified of the new releases and news of OakVar. 

.. _Subscribe to the mailing list: https://dashboard.mailerlite.com/forms/21170/56038572068701589/share

Medium: https://medium.com/oakvar

Discord: https://discord.gg/wZfkTMKTjG 

Reddit: https://www.reddit.com/r/oakvar

Email: rkim@oakbioinformatics.com

Many Thanks to Our Sponsors
=================================

Organizational Sponsors
-----------------------

.. image:: https://dna-seq.github.io/dna-seq/just_dna_seq.png
   :width: 225
   :alt: Just DNA-Seq
   :target: https://github.com/dna-seq

Individual Sponsors
-------------------

.. image:: https://avatars.githubusercontent.com/u/110073399?v=4
   :width: 50
   :alt: RegenCenter
   :target: https://github.com/RegenCenter

License
*******

OakVar is licensed under dual licensing: 1) APGL v3 or higher and 2) paid subscription for commercial use. For full license information, see `LICENSE`_.

.. _LICENSE: https://github.com/rkimoakbioinformatics/oakvar/blob/master/LICENSE
